# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHSEG_METADATA = Metadata(
    id="576c0067650470dbfa8631765aae242b35b3480b.boutiques",
    name="mri_synthseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_segmentation_file: OutputPathType
    """Segmentation output(s)"""
    output_volume_csv: OutputPathType | None
    """CSV file with volumes for all structures and subjects"""
    output_qc_csv: OutputPathType | None
    """CSV file with QC scores for all subjects"""
    output_posteriors_file: OutputPathType | None
    """Posteriors output(s)"""
    resampled_images_file: OutputPathType | None
    """Resampled image(s)"""


def mri_synthseg(
    input_image: InputPathType,
    output_segmentation: str,
    cortex_parcellation: bool = False,
    robust_prediction: bool = False,
    fast_prediction: bool = False,
    clip_ct: bool = False,
    output_volume: str | None = None,
    output_qc: str | None = None,
    output_posteriors: str | None = None,
    resampled_images: str | None = None,
    image_patch_size: list[float] | None = None,
    threads: float | None = None,
    cpu: bool = False,
    version_1: bool = False,
    photo_synthseg: str | None = None,
    runner: Runner | None = None,
) -> MriSynthsegOutputs:
    """
    SynthSeg is a tool for brain image segmentation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Image(s) to segment. Can be a path to an image or to a\
            folder.
        output_segmentation: Segmentation output(s). Must be a folder if --i\
            designates a folder.
        cortex_parcellation: Perform cortex parcellation.
        robust_prediction: Use robust predictions (slower).
        fast_prediction: Bypass some processing for faster prediction.
        clip_ct: Clip CT scans in Hounsfield scale to [0, 80].
        output_volume: Output CSV file with volumes for all structures and\
            subjects.
        output_qc: Output CSV file with QC scores for all subjects.
        output_posteriors: Posteriors output(s). Must be a folder if --i\
            designates a folder.
        resampled_images: Resampled image(s). Must be a folder if --i is a\
            folder.
        image_patch_size: Only analyse an image patch of the given size.
        threads: Number of cores to be used. Default is 1.
        cpu: Enforce running with CPU rather than GPU.
        version_1: Use SynthSeg 1.0 (updated 25/06/22).
        photo_synthseg: Photo-SynthSeg: segment 3D reconstructed stack of\
            coronal dissection photos of the cerebrum; must be left, right, or\
            both.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHSEG_METADATA)
    cargs = []
    cargs.append("mri_synthseg")
    cargs.append(execution.input_file(input_image))
    cargs.append(output_segmentation)
    if cortex_parcellation:
        cargs.append("--parc")
    if robust_prediction:
        cargs.append("--robust")
    if fast_prediction:
        cargs.append("--fast")
    if clip_ct:
        cargs.append("--ct")
    if output_volume is not None:
        cargs.append(output_volume)
    if output_qc is not None:
        cargs.append(output_qc)
    if output_posteriors is not None:
        cargs.append(output_posteriors)
    if resampled_images is not None:
        cargs.append(resampled_images)
    if image_patch_size is not None:
        cargs.extend(map(str, image_patch_size))
    if threads is not None:
        cargs.append(str(threads))
    if cpu:
        cargs.append("--cpu")
    if version_1:
        cargs.append("--v1")
    if photo_synthseg is not None:
        cargs.append(photo_synthseg)
    ret = MriSynthsegOutputs(
        root=execution.output_file("."),
        output_segmentation_file=execution.output_file(output_segmentation),
        output_volume_csv=execution.output_file(output_volume) if (output_volume is not None) else None,
        output_qc_csv=execution.output_file(output_qc) if (output_qc is not None) else None,
        output_posteriors_file=execution.output_file(output_posteriors) if (output_posteriors is not None) else None,
        resampled_images_file=execution.output_file(resampled_images) if (resampled_images is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHSEG_METADATA",
    "MriSynthsegOutputs",
    "mri_synthseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_METRICS_METADATA = Metadata(
    id="5e58dccd9bd1540ac2ae342efc61a7a9fc45c4c2.boutiques",
    name="SurfaceMetrics",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfaceMetricsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_metrics(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_metrics(
    surf1: str,
    internal_nodes: bool = False,
    internal_nodes_: bool = False,
    internal_nodes_2: bool = False,
    internal_nodes_3: bool = False,
    internal_nodes_4: bool = False,
    internal_nodes_5: bool = False,
    internal_nodes_6: bool = False,
    internal_nodes_7: bool = False,
    internal_nodes_8: bool = False,
    internal_nodes_9: bool = False,
    internal_nodes_10: bool = False,
    internal_nodes_11: bool = False,
    internal_nodes_12: bool = False,
    internal_nodes_13: bool = False,
    internal_nodes_14: bool = False,
    internal_nodes_15: bool = False,
    internal_nodes_16: bool = False,
    internal_nodes_17: bool = False,
    internal_nodes_18: bool = False,
    internal_nodes_19: bool = False,
    tlrc: bool = False,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> SurfaceMetricsOutputs:
    """
    Outputs information about a surface's mesh.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        surf1: Specifies the input surface.
        internal_nodes: Output nodes that are not a boundary.
        internal_nodes_: Output nodes that are not a boundary.
        internal_nodes_2: Output nodes that are not a boundary.
        internal_nodes_3: Output nodes that are not a boundary.
        internal_nodes_4: Output nodes that are not a boundary.
        internal_nodes_5: Output nodes that are not a boundary.
        internal_nodes_6: Output nodes that are not a boundary.
        internal_nodes_7: Output nodes that are not a boundary.
        internal_nodes_8: Output nodes that are not a boundary.
        internal_nodes_9: Output nodes that are not a boundary.
        internal_nodes_10: Output nodes that are not a boundary.
        internal_nodes_11: Output nodes that are not a boundary.
        internal_nodes_12: Output nodes that are not a boundary.
        internal_nodes_13: Output nodes that are not a boundary.
        internal_nodes_14: Output nodes that are not a boundary.
        internal_nodes_15: Output nodes that are not a boundary.
        internal_nodes_16: Output nodes that are not a boundary.
        internal_nodes_17: Output nodes that are not a boundary.
        internal_nodes_18: Output nodes that are not a boundary.
        internal_nodes_19: Output nodes that are not a boundary.
        tlrc: Apply Talairach transform to surface.
        prefix: Use prefix for output files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceMetricsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_METRICS_METADATA)
    cargs = []
    cargs.append("SurfaceMetrics")
    if internal_nodes:
        cargs.append("-internal_nodes")
    if internal_nodes_:
        cargs.append("-internal_nodes")
    if internal_nodes_2:
        cargs.append("-internal_nodes")
    if internal_nodes_3:
        cargs.append("-internal_nodes")
    if internal_nodes_4:
        cargs.append("-internal_nodes")
    if internal_nodes_5:
        cargs.append("-internal_nodes")
    if internal_nodes_6:
        cargs.append("-internal_nodes")
    if internal_nodes_7:
        cargs.append("-internal_nodes")
    if internal_nodes_8:
        cargs.append("-internal_nodes")
    if internal_nodes_9:
        cargs.append("-internal_nodes")
    if internal_nodes_10:
        cargs.append("-internal_nodes")
    if internal_nodes_11:
        cargs.append("-internal_nodes")
    if internal_nodes_12:
        cargs.append("-internal_nodes")
    if internal_nodes_13:
        cargs.append("-internal_nodes")
    if internal_nodes_14:
        cargs.append("-internal_nodes")
    if internal_nodes_15:
        cargs.append("-internal_nodes")
    if internal_nodes_16:
        cargs.append("-internal_nodes")
    if internal_nodes_17:
        cargs.append("-internal_nodes")
    if internal_nodes_18:
        cargs.append("-internal_nodes")
    if internal_nodes_19:
        cargs.append("-internal_nodes")
    cargs.extend([
        "-SURF_1",
        surf1
    ])
    if tlrc:
        cargs.append("-tlrc")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = SurfaceMetricsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_METRICS_METADATA",
    "SurfaceMetricsOutputs",
    "surface_metrics",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_FIBER_ORIENTATIONS_METADATA = Metadata(
    id="83932f9e32b874b47a5a87d2605029dbebc92a5c.boutiques",
    name="convert-fiber-orientations",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class ConvertFiberOrientationsFiber:
    """
    specify the parameter volumes for a fiber.
    """
    mean_f: InputPathType
    """mean fiber strength"""
    stdev_f: InputPathType
    """standard deviation of fiber strength"""
    theta: InputPathType
    """theta angle"""
    phi: InputPathType
    """phi angle"""
    psi: InputPathType
    """psi angle"""
    ka: InputPathType
    """ka bingham parameter"""
    kb: InputPathType
    """kb bingham parameter"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fiber")
        cargs.append(execution.input_file(self.mean_f))
        cargs.append(execution.input_file(self.stdev_f))
        cargs.append(execution.input_file(self.theta))
        cargs.append(execution.input_file(self.phi))
        cargs.append(execution.input_file(self.psi))
        cargs.append(execution.input_file(self.ka))
        cargs.append(execution.input_file(self.kb))
        return cargs


class ConvertFiberOrientationsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_fiber_orientations(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fiber_out: OutputPathType
    """the output fiber orientation file"""


def convert_fiber_orientations(
    label_volume: InputPathType,
    fiber_out: str,
    fiber: list[ConvertFiberOrientationsFiber] | None = None,
    runner: Runner | None = None,
) -> ConvertFiberOrientationsOutputs:
    """
    Convert bingham parameter volumes to fiber orientation file.
    
    Takes precomputed bingham parameters from volume files and converts them to
    the format workbench uses for display. The <label-volume> argument must be a
    label volume, where the labels use these strings:
    
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_volume: volume of cifti structure labels.
        fiber_out: the output fiber orientation file.
        fiber: specify the parameter volumes for a fiber.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertFiberOrientationsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_FIBER_ORIENTATIONS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-fiber-orientations")
    cargs.append(execution.input_file(label_volume))
    cargs.append(fiber_out)
    if fiber is not None:
        cargs.extend([a for c in [s.run(execution) for s in fiber] for a in c])
    ret = ConvertFiberOrientationsOutputs(
        root=execution.output_file("."),
        fiber_out=execution.output_file(fiber_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_FIBER_ORIENTATIONS_METADATA",
    "ConvertFiberOrientationsFiber",
    "ConvertFiberOrientationsOutputs",
    "convert_fiber_orientations",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TKREGISTER2_METADATA = Metadata(
    id="5b91df2c41f022fb3500d5826ced751292eade8d.boutiques",
    name="tkregister2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Tkregister2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `tkregister2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_reg_file: OutputPathType
    """Resulting registration file"""


def tkregister2(
    fixed_volume: InputPathType,
    moving_volume: InputPathType,
    reg_file: InputPathType,
    noedit: bool = False,
    lta: bool = False,
    surf_reg: bool = False,
    reg_only: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> Tkregister2Outputs:
    """
    tkregister2 is a tool from FreeSurfer used for registration of MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        fixed_volume: Fixed volume (e.g., anatomical image).
        moving_volume: Moving volume (e.g., functional image).
        reg_file: Registration file to be saved or loaded.
        noedit: Run in no-edit mode, useful for scripting.
        lta: Use LTA format for registration file.
        surf_reg: Use surface registration.
        reg_only: Don't show GUI, just save registration.
        help_: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tkregister2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TKREGISTER2_METADATA)
    cargs = []
    cargs.append("tkregister2")
    cargs.append(execution.input_file(fixed_volume))
    cargs.append(execution.input_file(moving_volume))
    cargs.append(execution.input_file(reg_file))
    if noedit:
        cargs.append("--noedit")
    if lta:
        cargs.append("--lta")
    if surf_reg:
        cargs.append("--surf")
    if reg_only:
        cargs.append("--regonly")
    if help_:
        cargs.append("--help")
    ret = Tkregister2Outputs(
        root=execution.output_file("."),
        output_reg_file=execution.output_file(pathlib.Path(reg_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TKREGISTER2_METADATA",
    "Tkregister2Outputs",
    "tkregister2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRANSFORMCONVERT_METADATA = Metadata(
    id="75054a4be3e9dc5460e5441d97e2350d859886dd.boutiques",
    name="transformconvert",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TransformconvertConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TransformconvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `transformconvert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output transformation matrix."""


def transformconvert(
    input_: list[str],
    operation: str,
    output: str,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TransformconvertConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TransformconvertOutputs:
    """
    Convert linear transformation matrices.
    
    This command allows to convert transformation matrices provided by other
    registration softwares to a format usable in MRtrix3. Example usages are
    provided below.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: the input(s) for the specified operation.
        operation: the operation to perform, one of:\
            flirt_import, itk_import.
        output: the output transformation matrix.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TransformconvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRANSFORMCONVERT_METADATA)
    cargs = []
    cargs.append("transformconvert")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend(input_)
    cargs.append(operation)
    cargs.append(output)
    ret = TransformconvertOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRANSFORMCONVERT_METADATA",
    "TransformconvertConfig",
    "TransformconvertOutputs",
    "transformconvert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRACTSTATS2TABLE_METADATA = Metadata(
    id="38161452219ff5617b56510006b0303c43a0164f.boutiques",
    name="tractstats2table",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Tractstats2tableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tractstats2table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_tablefile: OutputPathType
    """The output table file."""


def tractstats2table(
    tablefile: InputPathType,
    inputs: list[str] | None = None,
    load_pathstats_from_file: InputPathType | None = None,
    overall: bool = False,
    byvoxel: bool = False,
    byvoxel_measure: typing.Literal["AD", "RD", "MD", "FA"] | None = None,
    delimiter: typing.Literal["tab", "comma", "space", "semicolon"] | None = "tab",
    transpose: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> Tractstats2tableOutputs:
    """
    Converts a track overall stats file created by tracula into a table used for
    group statistics.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        tablefile: The output table file.
        inputs: Specify input stat files.
        load_pathstats_from_file: Name of the file which has the list of\
            subjects (one subject per line).
        overall: Operate on the overall path statistics.
        byvoxel: Operate on the byvoxel path statistics.
        byvoxel_measure: Specify byvoxel measure. One of [AD, RD, MD, FA].\
            Required with --byvoxel option.
        delimiter: Delimiter between measures in the table. Default is tab (alt\
            comma, space, semicolon).
        transpose: Transpose the table (default is subject in rows and\
            measures/count in cols).
        debug: Increase verbosity.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tractstats2tableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRACTSTATS2TABLE_METADATA)
    cargs = []
    cargs.append("tractstats2table")
    if inputs is not None:
        cargs.extend([
            "--inputs",
            *inputs
        ])
    if load_pathstats_from_file is not None:
        cargs.extend([
            "--load-pathstats-from-file",
            execution.input_file(load_pathstats_from_file)
        ])
    if overall:
        cargs.append("-o")
    if byvoxel:
        cargs.append("-b")
    if byvoxel_measure is not None:
        cargs.extend([
            "--byvoxel-measure",
            byvoxel_measure
        ])
    cargs.extend([
        "-t",
        execution.input_file(tablefile)
    ])
    if delimiter is not None:
        cargs.extend([
            "-d",
            delimiter
        ])
    if transpose:
        cargs.append("--transpose")
    if debug:
        cargs.append("-v")
    ret = Tractstats2tableOutputs(
        root=execution.output_file("."),
        output_tablefile=execution.output_file(pathlib.Path(tablefile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRACTSTATS2TABLE_METADATA",
    "Tractstats2tableOutputs",
    "tractstats2table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA = Metadata(
    id="e28b7723dc233ae33bddb7baaceb4212b4fd873b.boutiques",
    name="convert-matrix4-to-workbench-sparse",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class ConvertMatrix4ToWorkbenchSparseVolumeSeeds:
    """
    specify the volume seed space.
    """
    cifti_template: InputPathType
    """cifti file to use the volume mappings from"""
    direction: str
    """dimension along the cifti file to take the mapping from, ROW or COLUMN"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-seeds")
        cargs.append(execution.input_file(self.cifti_template))
        cargs.append(self.direction)
        return cargs


class ConvertMatrix4ToWorkbenchSparseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_matrix4_to_workbench_sparse(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_matrix4_to_workbench_sparse(
    matrix4_1: str,
    matrix4_2: str,
    matrix4_3: str,
    orientation_file: InputPathType,
    voxel_list: str,
    wb_sparse_out: str,
    opt_surface_seeds_seed_roi: InputPathType | None = None,
    volume_seeds: ConvertMatrix4ToWorkbenchSparseVolumeSeeds | None = None,
    runner: Runner | None = None,
) -> ConvertMatrix4ToWorkbenchSparseOutputs:
    """
    Convert a 3-file matrix4 to a workbench sparse file.
    
    Converts the matrix 4 output of probtrackx to workbench sparse file format.
    Exactly one of -surface-seeds and -volume-seeds must be specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        matrix4_1: the first matrix4 file.
        matrix4_2: the second matrix4 file.
        matrix4_3: the third matrix4 file.
        orientation_file: the .fiberTEMP.nii file this trajectory file applies\
            to.
        voxel_list: list of white matter voxel index triplets as used in the\
            trajectory matrix.
        wb_sparse_out: output - the output workbench sparse file.
        opt_surface_seeds_seed_roi: specify the surface seed space: metric roi\
            file of all vertices used in the seed space.
        volume_seeds: specify the volume seed space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertMatrix4ToWorkbenchSparseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-matrix4-to-workbench-sparse")
    cargs.append(matrix4_1)
    cargs.append(matrix4_2)
    cargs.append(matrix4_3)
    cargs.append(execution.input_file(orientation_file))
    cargs.append(voxel_list)
    cargs.append(wb_sparse_out)
    if opt_surface_seeds_seed_roi is not None:
        cargs.extend([
            "-surface-seeds",
            execution.input_file(opt_surface_seeds_seed_roi)
        ])
    if volume_seeds is not None:
        cargs.extend(volume_seeds.run(execution))
    ret = ConvertMatrix4ToWorkbenchSparseOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_MATRIX4_TO_WORKBENCH_SPARSE_METADATA",
    "ConvertMatrix4ToWorkbenchSparseOutputs",
    "ConvertMatrix4ToWorkbenchSparseVolumeSeeds",
    "convert_matrix4_to_workbench_sparse",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMAXIMA_METADATA = Metadata(
    id="f8ba8da054bfe915efd0d6532d6b8fe26bfcc7a9.boutiques",
    name="3dmaxima",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaximaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmaxima(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType | None
    """Output mask dataset with extrema locations"""


def v_3dmaxima(
    input_dataset: InputPathType,
    output_prefix: str | None = None,
    threshold: float | None = None,
    min_dist: float | None = None,
    out_rad: float | None = None,
    input_flag: bool = False,
    spheres_1_flag: bool = False,
    spheres_1to_n_flag: bool = False,
    spheres_nto1_flag: bool = False,
    neg_ext_flag: bool = False,
    true_max_flag: bool = False,
    dset_coords_flag: bool = False,
    no_text_flag: bool = False,
    coords_only_flag: bool = False,
    n_style_sort_flag: bool = False,
    n_style_weight_ave_flag: bool = False,
    debug_level: float | None = None,
    help_flag: bool = False,
    hist_flag: bool = False,
    ver_flag: bool = False,
    runner: Runner | None = None,
) -> V3dmaximaOutputs:
    """
    Locate extrema in a functional dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Specify input dataset (e.g. func+orig'[7]').
        output_prefix: Prefix for an output mask dataset (e.g. -prefix\
            maskNto1).
        threshold: Provides a cutoff value for extrema (e.g. -thresh 17.4).
        min_dist: Minimum acceptable distance between extrema in voxels (e.g.\
            -min_dist 4).
        out_rad: Set the output radius around extrema voxels in voxel units\
            (e.g. -out_rad 9).
        input_flag: Specify input dataset (e.g. -input func+orig'[7]').
        spheres_1_flag: Set all output values to 1.
        spheres_1to_n_flag: Output values will range from 1 to N.
        spheres_nto1_flag: Output values will range from N to 1.
        neg_ext_flag: Search for negative extrema (minima).
        true_max_flag: Extrema may not have equal neighbors.
        dset_coords_flag: Display output in the dataset orientation.
        no_text_flag: Do not display the extrema points as text.
        coords_only_flag: Only output coordinates (no text or values).
        n_style_sort_flag: Use 'Sort-n-Remove' style (default).
        n_style_weight_ave_flag: Use 'Weighted-Average' style.
        debug_level: Output extra information to the terminal (e.g. -debug 2).
        help_flag: Display help information.
        hist_flag: Display module history.
        ver_flag: Display version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaximaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMAXIMA_METADATA)
    cargs = []
    cargs.append("3dmaxima")
    cargs.append(execution.input_file(input_dataset))
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if threshold is not None:
        cargs.extend([
            "-thresh",
            str(threshold)
        ])
    if min_dist is not None:
        cargs.extend([
            "-min_dist",
            str(min_dist)
        ])
    if out_rad is not None:
        cargs.extend([
            "-out_rad",
            str(out_rad)
        ])
    if input_flag:
        cargs.append("-input")
    if spheres_1_flag:
        cargs.append("-spheres_1")
    if spheres_1to_n_flag:
        cargs.append("-spheres_1toN")
    if spheres_nto1_flag:
        cargs.append("-spheres_Nto1")
    if neg_ext_flag:
        cargs.append("-neg_ext")
    if true_max_flag:
        cargs.append("-true_max")
    if dset_coords_flag:
        cargs.append("-dset_coords")
    if no_text_flag:
        cargs.append("-no_text")
    if coords_only_flag:
        cargs.append("-coords_only")
    if n_style_sort_flag:
        cargs.append("-n_style_sort")
    if n_style_weight_ave_flag:
        cargs.append("-n_style_weight_ave")
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if help_flag:
        cargs.append("-help")
    if hist_flag:
        cargs.append("-hist")
    if ver_flag:
        cargs.append("-ver")
    ret = V3dmaximaOutputs(
        root=execution.output_file("."),
        output_mask=execution.output_file(output_prefix + "_mask+orig.[HEAD | BRIK]") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaximaOutputs",
    "V_3DMAXIMA_METADATA",
    "v_3dmaxima",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRGRID_METADATA = Metadata(
    id="38b5784d2ea0ffb125cf48797846326fbc4d3517.boutiques",
    name="mrgrid",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrgridAxis:
    """
    pad or crop the input image along the provided axis (defined by index). The
    specifier argument defines the number of voxels added or removed on the
    lower or upper end of the axis (-axis index delta_lower,delta_upper) or acts
    as a voxel selection range (-axis index start:stop). In both modes, values
    are relative to the input image (overriding all other extent-specifying
    options). Negative delta specifier values trigger the inverse operation (pad
    instead of crop and vice versa) and negative range specifier trigger
    padding. Note that the deprecated commands 'mrcrop' and 'mrpad' used
    range-based and delta-based -axis indices, respectively.
    """
    index: int
    """pad or crop the input image along the provided axis (defined by index).
    The specifier argument defines the number of voxels added or removed on the
    lower or upper end of the axis (-axis index delta_lower,delta_upper) or acts
    as a voxel selection range (-axis index start:stop). In both modes, values
    are relative to the input image (overriding all other extent-specifying
    options). Negative delta specifier values trigger the inverse operation (pad
    instead of crop and vice versa) and negative range specifier trigger
    padding. Note that the deprecated commands 'mrcrop' and 'mrpad' used
    range-based and delta-based -axis indices, respectively."""
    spec: str
    """pad or crop the input image along the provided axis (defined by index).
    The specifier argument defines the number of voxels added or removed on the
    lower or upper end of the axis (-axis index delta_lower,delta_upper) or acts
    as a voxel selection range (-axis index start:stop). In both modes, values
    are relative to the input image (overriding all other extent-specifying
    options). Negative delta specifier values trigger the inverse operation (pad
    instead of crop and vice versa) and negative range specifier trigger
    padding. Note that the deprecated commands 'mrcrop' and 'mrpad' used
    range-based and delta-based -axis indices, respectively."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-axis")
        cargs.append(str(self.index))
        cargs.append(self.spec)
        return cargs


@dataclasses.dataclass
class MrgridVariousString:
    obj: str
    """String object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.obj)
        return cargs


@dataclasses.dataclass
class MrgridVariousFile:
    obj: InputPathType
    """File object."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.obj))
        return cargs


@dataclasses.dataclass
class MrgridConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrgridOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrgrid(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image."""


def mrgrid(
    input_: InputPathType,
    operation: str,
    output: str,
    template: InputPathType | None = None,
    size: list[int] | None = None,
    voxel: list[float] | None = None,
    scale: list[float] | None = None,
    interp: str | None = None,
    oversample: list[int] | None = None,
    as_: InputPathType | None = None,
    uniform: int | None = None,
    mask: InputPathType | None = None,
    crop_unbound: bool = False,
    axis: list[MrgridAxis] | None = None,
    all_axes: bool = False,
    fill: float | None = None,
    strides: typing.Union[MrgridVariousString, MrgridVariousFile] | None = None,
    datatype: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrgridConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrgridOutputs:
    """
    Modify the grid of an image without interpolation (cropping or padding) or by
    regridding to an image grid with modified orientation, location and or
    resolution. The image content remains in place in real world coordinates..
    
    - regrid: This operation performs changes of the voxel grid that require
    interpolation of the image such as changing the resolution or location and
    orientation of the voxel grid. If the image is down-sampled, the appropriate
    smoothing is automatically applied using Gaussian smoothing unless nearest
    neighbour interpolation is selected or oversample is changed explicitly. The
    resolution can only be changed for spatial dimensions.
    
    - crop: The image extent after cropping, can be specified either manually
    for each axis dimensions, or via a mask or reference image. The image can be
    cropped to the extent of a mask. This is useful for axially-acquired brain
    images, where the image size can be reduced by a factor of 2 by removing the
    empty space on either side of the brain. Note that cropping does not extend
    the image beyond the original FOV unless explicitly specified (via
    -crop_unbound or negative -axis extent).
    
    - pad: Analogously to cropping, padding increases the FOV of an image
    without image interpolation. Pad and crop can be performed simultaneously by
    specifying signed specifier argument values to the -axis option.
    
    This command encapsulates and extends the functionality of the superseded
    commands 'mrpad', 'mrcrop' and 'mrresize'. Note the difference in -axis
    convention used for 'mrcrop' and 'mrpad' (see -axis option description).
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_: input image to be regridded.
        operation: the operation to be performed, one of: regrid, crop, pad.
        output: the output image.
        template: match the input image grid (voxel spacing, image size, header\
            transformation) to that of a reference image. The image resolution\
            relative to the template image can be changed with one of -size,\
            -voxel, -scale.
        size: define the size (number of voxels) in each spatial dimension for\
            the output image. This should be specified as a comma-separated list.
        voxel: define the new voxel size for the output image. This can be\
            specified either as a single value to be used for all spatial\
            dimensions, or as a comma-separated list of the size for each voxel\
            dimension.
        scale: scale the image resolution by the supplied factor. This can be\
            specified either as a single value to be used for all dimensions, or as\
            a comma-separated list of scale factors for each dimension.
        interp: set the interpolation method to use when reslicing (choices:\
            nearest, linear, cubic, sinc. Default: cubic).
        oversample: set the amount of over-sampling (in the target space) to\
            perform when regridding. This is particularly relevant when downsamping\
            a high-resolution image to a low-resolution image, to avoid aliasing\
            artefacts. This can consist of a single integer, or a comma-separated\
            list of 3 integers if different oversampling factors are desired along\
            the different axes. Default is determined from ratio of voxel\
            dimensions (disabled for nearest-neighbour interpolation).
        as_: pad or crop the input image on the upper bound to match the\
            specified reference image grid. This operation ignores differences in\
            image transformation between input and reference image.
        uniform: pad or crop the input image by a uniform number of voxels on\
            all sides.
        mask: crop the input image according to the spatial extent of a mask\
            image. The mask must share a common voxel grid with the input image but\
            differences in image transformations are ignored. Note that even though\
            only 3 dimensions are cropped when using a mask, the bounds are\
            computed by checking the extent for all dimensions. Note that by\
            default a gap of 1 voxel is left at all edges of the image to allow\
            valid trilinear interpolation. This gap can be modified with the\
            -uniform option but by default it does not extend beyond the FOV unless\
            -crop_unbound is used.
        crop_unbound: Allow padding beyond the original FOV when cropping.
        axis: pad or crop the input image along the provided axis (defined by\
            index). The specifier argument defines the number of voxels added or\
            removed on the lower or upper end of the axis (-axis index\
            delta_lower,delta_upper) or acts as a voxel selection range (-axis\
            index start:stop). In both modes, values are relative to the input\
            image (overriding all other extent-specifying options). Negative delta\
            specifier values trigger the inverse operation (pad instead of crop and\
            vice versa) and negative range specifier trigger padding. Note that the\
            deprecated commands 'mrcrop' and 'mrpad' used range-based and\
            delta-based -axis indices, respectively.
        all_axes: Crop or pad all, not just spatial axes.
        fill: Use number as the out of bounds value. nan, inf and -inf are\
            valid arguments. (Default: 0.0).
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        datatype: specify output image data type. Valid choices are: float32,\
            float32le, float32be, float64, float64le, float64be, int64, uint64,\
            int64le, uint64le, int64be, uint64be, int32, uint32, int32le, uint32le,\
            int32be, uint32be, int16, uint16, int16le, uint16le, int16be, uint16be,\
            cfloat32, cfloat32le, cfloat32be, cfloat64, cfloat64le, cfloat64be,\
            int8, uint8, bit.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrgridOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRGRID_METADATA)
    cargs = []
    cargs.append("mrgrid")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if size is not None:
        cargs.extend([
            "-size",
            ",".join(map(str, size))
        ])
    if voxel is not None:
        cargs.extend([
            "-voxel",
            ",".join(map(str, voxel))
        ])
    if scale is not None:
        cargs.extend([
            "-scale",
            ",".join(map(str, scale))
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if oversample is not None:
        cargs.extend([
            "-oversample",
            ",".join(map(str, oversample))
        ])
    if as_ is not None:
        cargs.extend([
            "-as",
            execution.input_file(as_)
        ])
    if uniform is not None:
        cargs.extend([
            "-uniform",
            str(uniform)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if crop_unbound:
        cargs.append("-crop_unbound")
    if axis is not None:
        cargs.extend([a for c in [s.run(execution) for s in axis] for a in c])
    if all_axes:
        cargs.append("-all_axes")
    if fill is not None:
        cargs.extend([
            "-fill",
            str(fill)
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            *strides.run(execution)
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(operation)
    cargs.append(output)
    ret = MrgridOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRGRID_METADATA",
    "MrgridAxis",
    "MrgridConfig",
    "MrgridOutputs",
    "MrgridVariousFile",
    "MrgridVariousString",
    "mrgrid",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APARCSTATS2TABLE_METADATA = Metadata(
    id="7b7bfbf1a3b6bd57ebf50cd28aa6878555458f68.boutiques",
    name="aparcstats2table",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Aparcstats2tableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aparcstats2table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType
    """Output table file with processed data."""


def aparcstats2table(
    hemi: str,
    tablefile: InputPathType,
    subjects: list[str] | None = None,
    subjectsfile: InputPathType | None = None,
    qdec: InputPathType | None = None,
    qdec_long: InputPathType | None = None,
    parcellation: str | None = "aparc",
    measure: str | None = "area",
    delimiter: str | None = "tab",
    skip_missing: bool = False,
    parcid_only: bool = False,
    common_parcs: bool = False,
    parcs_file: InputPathType | None = None,
    report_rois: bool = False,
    transpose: bool = False,
    debug: bool = False,
    etiv: bool = False,
    scale: float | None = 1,
    runner: Runner | None = None,
) -> Aparcstats2tableOutputs:
    """
    Converts a cortical stats file into a table format with subjects as rows and
    parcellations as columns.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere being analyzed (lh or rh required).
        tablefile: Output table file.
        subjects: List of subject IDs.
        subjectsfile: File containing list of subjects (one per line).
        qdec: QDEC table file with subject IDs.
        qdec_long: Longitudinal QDEC table with subject templates.
        parcellation: Parcellation atlas (default: aparc).
        measure: Measure type (e.g., area, volume, thickness).
        delimiter: Delimiter between measures in the table (default: tab).
        skip_missing: Skip subjects if input is not found.
        parcid_only: Write only ROI names without pre/appended hemi/measure.
        common_parcs: Output only common parcellations across all subjects.
        parcs_file: File specifying which parcellations to output.
        report_rois: Print ROI information for each subject.
        transpose: Transpose the table (subjects in columns).
        debug: Increase verbosity.
        etiv: Report volume as percent estimated total intracranial volume.
        scale: Scale factor for output values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Aparcstats2tableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APARCSTATS2TABLE_METADATA)
    cargs = []
    cargs.append("aparcstats2table")
    if subjects is not None:
        cargs.extend([
            "--subjects",
            *subjects
        ])
    if subjectsfile is not None:
        cargs.extend([
            "--subjectsfile",
            execution.input_file(subjectsfile)
        ])
    if qdec is not None:
        cargs.extend([
            "--qdec",
            execution.input_file(qdec)
        ])
    if qdec_long is not None:
        cargs.extend([
            "--qdec-long",
            execution.input_file(qdec_long)
        ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    cargs.extend([
        "-t",
        execution.input_file(tablefile)
    ])
    if parcellation is not None:
        cargs.extend([
            "--parc",
            parcellation
        ])
    if measure is not None:
        cargs.extend([
            "-m",
            measure
        ])
    if delimiter is not None:
        cargs.extend([
            "-d",
            delimiter
        ])
    if skip_missing:
        cargs.append("--skip")
    if parcid_only:
        cargs.append("--parcid-only")
    if common_parcs:
        cargs.append("--common-parcs")
    if parcs_file is not None:
        cargs.extend([
            "--parcs-from-file",
            execution.input_file(parcs_file)
        ])
    if report_rois:
        cargs.append("--report-rois")
    if transpose:
        cargs.append("--transpose")
    if debug:
        cargs.append("-v")
    if etiv:
        cargs.append("--etiv")
    if scale is not None:
        cargs.extend([
            "--scale",
            str(scale)
        ])
    ret = Aparcstats2tableOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(pathlib.Path(tablefile).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APARCSTATS2TABLE_METADATA",
    "Aparcstats2tableOutputs",
    "aparcstats2table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_T1_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA = Metadata(
    id="3610f126955ba102d4ca3bfab514b11ee60bd328.boutiques",
    name="segmentSubjectT1T2_autoEstimateAlveusML",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectT1T2AutoEstimateAlveusMlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_t1_t2_auto_estimate_alveus_ml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_result: OutputPathType
    """Resultant image of the alveus segmentation."""


def segment_subject_t1_t2_auto_estimate_alveus_ml(
    input_t1: InputPathType,
    input_t2: InputPathType,
    output_directory: str,
    other_options: str | None = None,
    runner: Runner | None = None,
) -> SegmentSubjectT1T2AutoEstimateAlveusMlOutputs:
    """
    Tool for automatic estimation of the alveus in MR images using T1 and T2
    contrast.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_t1: Input T1-weighted MR image.
        input_t2: Input T2-weighted MR image.
        output_directory: Directory to save the output files.
        other_options: Additional command-line options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectT1T2AutoEstimateAlveusMlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_T1_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA)
    cargs = []
    cargs.append("segmentSubjectT1T2_autoEstimateAlveusML")
    cargs.append(execution.input_file(input_t1))
    cargs.append(execution.input_file(input_t2))
    cargs.append(output_directory)
    if other_options is not None:
        cargs.append(other_options)
    ret = SegmentSubjectT1T2AutoEstimateAlveusMlOutputs(
        root=execution.output_file("."),
        segmentation_result=execution.output_file(output_directory + "/segmentation.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_T1_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA",
    "SegmentSubjectT1T2AutoEstimateAlveusMlOutputs",
    "segment_subject_t1_t2_auto_estimate_alveus_ml",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BBREGISTER_METADATA = Metadata(
    id="06a9a3d42999005484cd3e30d110e491b2d7dca8.boutiques",
    name="bbregister",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BbregisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bbregister(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reg_output: OutputPathType
    """Output registration file in dat or lta format."""
    out_volume: OutputPathType
    """Resampled moveable volume."""


def bbregister(
    subject: str,
    moveable_volume: InputPathType,
    reg_file: str,
    contrast_type_t2: bool = False,
    runner: Runner | None = None,
) -> BbregisterOutputs:
    """
    Performs within-subject, cross-modal registration using a boundary-based cost
    function.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: FreeSurfer subject name as found in $SUBJECTS_DIR.
        moveable_volume: "Moveable" volume template for cross-modal volume.\
            E.g., fMRI volume used for motion correction.
        reg_file: Output FreeSurfer registration file (tkregister-style or LTA\
            format).
        contrast_type_t2: Assume T2 contrast, Grey Matter brighter than White\
            Matter. Same as --bold and --dti.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BbregisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BBREGISTER_METADATA)
    cargs = []
    cargs.append("bbregister")
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--mov",
        execution.input_file(moveable_volume)
    ])
    cargs.extend([
        "--reg",
        reg_file
    ])
    if contrast_type_t2:
        cargs.append("--t2")
    cargs.append("[OPTIONS]")
    ret = BbregisterOutputs(
        root=execution.output_file("."),
        reg_output=execution.output_file(reg_file),
        out_volume=execution.output_file("[O_OUTVOL]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BBREGISTER_METADATA",
    "BbregisterOutputs",
    "bbregister",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FUSE_SEGMENTATIONS_METADATA = Metadata(
    id="b42ea2ffd32b62f852b2f074e21005b3ac5e5519.boutiques",
    name="mri_fuse_segmentations",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFuseSegmentationsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fuse_segmentations(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Resulting fused segmentation as aseg.fused.mgz file"""


def mri_fuse_segmentations(
    asegs: list[InputPathType],
    nocc_asegs: list[InputPathType],
    norm_volumes: list[InputPathType],
    input_file: InputPathType,
    transforms: list[InputPathType] | None = None,
    sigma: float | None = 3.0,
    runner: Runner | None = None,
) -> MriFuseSegmentationsOutputs:
    """
    Fuse a set of segmentations (asegs) into an initial estimate of a longitudinal
    one.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        asegs: Path to aseg.mgz files, one per TP.
        nocc_asegs: Path to aseg.auto_noCCseg.mgz files without CC labels, one\
            per TP.
        norm_volumes: Path to norm.mgz files, one per TP.
        input_file: Input norm.mgz file.
        transforms: Transform files from each TP to the input norm.mgz, can be\
            LTA, M3Z or identity.nofile.
        sigma: Cross-time sigma (default 3.0).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFuseSegmentationsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FUSE_SEGMENTATIONS_METADATA)
    cargs = []
    cargs.append("mri_fuse_segmentations")
    cargs.extend([
        "-a",
        *[execution.input_file(f) for f in asegs]
    ])
    cargs.extend([
        "-c",
        *[execution.input_file(f) for f in nocc_asegs]
    ])
    cargs.extend([
        "-n",
        *[execution.input_file(f) for f in norm_volumes]
    ])
    if transforms is not None:
        cargs.extend([
            "-t",
            *[execution.input_file(f) for f in transforms]
        ])
    if sigma is not None:
        cargs.extend([
            "-s",
            str(sigma)
        ])
    cargs.append(execution.input_file(input_file))
    cargs.append("[OUTPUT]")
    ret = MriFuseSegmentationsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FUSE_SEGMENTATIONS_METADATA",
    "MriFuseSegmentationsOutputs",
    "mri_fuse_segmentations",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_PARCELLATE_CONNECTIVITY_METADATA = Metadata(
    id="0c3b840a03cfbf5cf09f4768e47a63ba51235eb2.boutiques",
    name="mris_parcellate_connectivity",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisParcellateConnectivityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_parcellate_connectivity(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    parcellation_output: OutputPathType
    """The resulting output parcellation."""


def mris_parcellate_connectivity(
    input_surface: InputPathType,
    input_correlations: InputPathType,
    output_parcellation: str,
    smooth_iterations: float | None = None,
    runner: Runner | None = None,
) -> MrisParcellateConnectivityOutputs:
    """
    A tool to parcellate brain connectivity using surface and correlation data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        input_correlations: Input correlations file.
        output_parcellation: Output parcellation file.
        smooth_iterations: Number of averaging iterations for smoothing\
            correlation matrix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisParcellateConnectivityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_PARCELLATE_CONNECTIVITY_METADATA)
    cargs = []
    cargs.append("mris_parcellate_connectivity")
    if smooth_iterations is not None:
        cargs.extend([
            "-n",
            str(smooth_iterations)
        ])
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(input_correlations))
    cargs.append(output_parcellation)
    ret = MrisParcellateConnectivityOutputs(
        root=execution.output_file("."),
        parcellation_output=execution.output_file(output_parcellation),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_PARCELLATE_CONNECTIVITY_METADATA",
    "MrisParcellateConnectivityOutputs",
    "mris_parcellate_connectivity",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_AFFINE_METADATA = Metadata(
    id="3b8860ef222f898c6a65c82c6ffa70dc64abc45b.boutiques",
    name="convert-affine",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class ConvertAffineFromWorld:
    """
    input is a NIFTI 'world' affine.
    """
    input_: str
    """the input affine"""
    opt_inverse: bool = False
    """for files that use 'target to source' convention"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-world")
        cargs.append(self.input_)
        if self.opt_inverse:
            cargs.append("-inverse")
        return cargs


@dataclasses.dataclass
class ConvertAffineFromFlirt:
    """
    input is a flirt matrix.
    """
    input_: str
    """the input affine"""
    source_volume: str
    """the source volume used when generating the input affine"""
    target_volume: str
    """the target volume used when generating the input affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-flirt")
        cargs.append(self.input_)
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


@dataclasses.dataclass
class ConvertAffineToWorld:
    """
    write output as a NIFTI 'world' affine.
    """
    output: str
    """output - the output affine"""
    opt_inverse: bool = False
    """write file using 'target to source' convention"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-to-world")
        cargs.append(self.output)
        if self.opt_inverse:
            cargs.append("-inverse")
        return cargs


@dataclasses.dataclass
class ConvertAffineToFlirt:
    """
    write output as a flirt matrix.
    """
    output: str
    """output - the output affine"""
    source_volume: str
    """the volume you want to apply the transform to"""
    target_volume: str
    """the target space you want the transformed volume to match"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-to-flirt")
        cargs.append(self.output)
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


class ConvertAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_affine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_affine(
    from_world: ConvertAffineFromWorld | None = None,
    opt_from_itk_input: str | None = None,
    from_flirt: ConvertAffineFromFlirt | None = None,
    to_world: ConvertAffineToWorld | None = None,
    opt_to_itk_output: str | None = None,
    to_flirt: list[ConvertAffineToFlirt] | None = None,
    runner: Runner | None = None,
) -> ConvertAffineOutputs:
    """
    Convert an affine file between conventions.
    
    NIFTI world matrices can be used directly on mm coordinates via matrix
    multiplication, they use the NIFTI coordinate system, that is, positive X is
    right, positive Y is anterior, and positive Z is superior. Note that
    wb_command assumes that world matrices transform source coordinates to
    target coordinates, while other tools may use affines that transform target
    coordinates to source coordinates.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-flirt may be specified more than once.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        from_world: input is a NIFTI 'world' affine.
        opt_from_itk_input: input is an ITK matrix: the input affine.
        from_flirt: input is a flirt matrix.
        to_world: write output as a NIFTI 'world' affine.
        opt_to_itk_output: write output as an ITK affine: output - the output\
            affine.
        to_flirt: write output as a flirt matrix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_AFFINE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-affine")
    if from_world is not None:
        cargs.extend(from_world.run(execution))
    if opt_from_itk_input is not None:
        cargs.extend([
            "-from-itk",
            opt_from_itk_input
        ])
    if from_flirt is not None:
        cargs.extend(from_flirt.run(execution))
    if to_world is not None:
        cargs.extend(to_world.run(execution))
    if opt_to_itk_output is not None:
        cargs.extend([
            "-to-itk",
            opt_to_itk_output
        ])
    if to_flirt is not None:
        cargs.extend([a for c in [s.run(execution) for s in to_flirt] for a in c])
    ret = ConvertAffineOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_AFFINE_METADATA",
    "ConvertAffineFromFlirt",
    "ConvertAffineFromWorld",
    "ConvertAffineOutputs",
    "ConvertAffineToFlirt",
    "ConvertAffineToWorld",
    "convert_affine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VERTEXVOL_METADATA = Metadata(
    id="43f2f0ece18dc9707df38e81102c8d727e4682e9.boutiques",
    name="vertexvol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class VertexvolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vertexvol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType | None
    """Output file containing vertex-wise volume"""


def vertexvol(
    subject: str,
    right_hemisphere: bool = False,
    output_file: str | None = "?h.volume",
    no_th3: bool = False,
    runner: Runner | None = None,
) -> VertexvolOutputs:
    """
    Computes vertex-wise volume (and mid.area).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        right_hemisphere: Select right hemisphere.
        output_file: Output file name, default is ?h.volume.
        no_th3: Don't use TH3 method for computation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VertexvolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VERTEXVOL_METADATA)
    cargs = []
    cargs.append("vertexvol")
    cargs.extend([
        "--s",
        subject
    ])
    if right_hemisphere:
        cargs.append("--rh")
    if output_file is not None:
        cargs.extend([
            "--o",
            output_file
        ])
    if no_th3:
        cargs.append("--no-th3")
    ret = VertexvolOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VERTEXVOL_METADATA",
    "VertexvolOutputs",
    "vertexvol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFREG_METADATA = Metadata(
    id="68e84766e8130637a36f745fc7308f0bf775b2d7.boutiques",
    name="surfreg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SurfregOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surfreg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface registration file"""


def surfreg(
    subject: str,
    target: str,
    cross_hemi: bool = False,
    reg_lh: bool = False,
    reg_rh: bool = False,
    reg_both: bool = False,
    no_annot: bool = False,
    annot: str | None = None,
    aparc: bool = False,
    noneg: bool = False,
    init_reg: str | None = None,
    lta: str | None = None,
    init_from_tal: bool = False,
    outsurf: str | None = None,
    no_set_vol_geom: bool = False,
    threads: float | None = None,
    runner: Runner | None = None,
) -> SurfregOutputs:
    """
    Performs surface registration (mris_register) between a subject and a target
    average subject based on the hemi.reg.template.tif atlas in the average subject.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject to register.
        target: Target average subject to use as a registration target.
        cross_hemi: Perform cross-hemi registration.
        reg_lh: Register left hemisphere only.
        reg_rh: Register right hemisphere only.
        reg_both: Register both left and right hemispheres.
        no_annot: Do not use annot to rip.
        annot: Use specified annotation name.
        aparc: Set annotation name to aparc.annot.
        noneg: Option flag with unspecified behavior in the provided help text.
        init_reg: Initial registration name, default is sphere.
        lta: Apply rotational components of affine registration.
        init_from_tal: Use talaiach.xfm.lta for initial spherical registration.
        outsurf: Output surface name, default depends on the target.
        no_set_vol_geom: Do not set volume geometry and center the sphere.
        threads: Number of threads to run in parallel.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfregOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFREG_METADATA)
    cargs = []
    cargs.append("surfreg")
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--t",
        target
    ])
    if cross_hemi:
        cargs.append("--xhemi")
    if reg_lh:
        cargs.append("--lh")
    if reg_rh:
        cargs.append("--rh")
    if reg_both:
        cargs.append("--lhrh")
    if no_annot:
        cargs.append("--no-annot")
    if annot is not None:
        cargs.extend([
            "--annot",
            annot
        ])
    if aparc:
        cargs.append("--aparc")
    if noneg:
        cargs.append("--noneg")
    if init_reg is not None:
        cargs.extend([
            "--init-reg",
            init_reg
        ])
    if lta is not None:
        cargs.extend([
            "--lta",
            lta
        ])
    if init_from_tal:
        cargs.append("--init-from-tal")
    if outsurf is not None:
        cargs.extend([
            "--o",
            outsurf
        ])
    if no_set_vol_geom:
        cargs.append("--no-set-vol-geom")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    ret = SurfregOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file("subject/surf/hemi.target.sphere.reg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFREG_METADATA",
    "SurfregOutputs",
    "surfreg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTSINTEGRATE_VECTOR_FIELD_METADATA = Metadata(
    id="25eaf01e25105beba3ae7eb2187714401340f8d4.boutiques",
    name="ANTSIntegrateVectorField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsintegrateVectorFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `antsintegrate_vector_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fibers_out_vtk: OutputPathType
    """The output is the fibers as a VTK text file."""
    length_image_out_nii: OutputPathType
    """The output is the length image."""


def antsintegrate_vector_field(
    vector_field_input: InputPathType,
    roi_mask_input: InputPathType,
    fibers_output: str,
    length_image_output: str,
    runner: Runner | None = None,
) -> AntsintegrateVectorFieldOutputs:
    """
    This tool integrates a vector field, where vectors are voxels, using a region of
    interest (ROI) mask. The ROI mask controls where the integration is performed
    and specifies the starting point region.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        vector_field_input: Input vector field image (e.g., VecImageIN.nii.gz),\
            where vectors are voxels.
        roi_mask_input: Input ROI mask image (e.g., ROIMaskIN.nii.gz), an\
            integer image controlling where the integration is performed.
        fibers_output: Output VTK text file for fibers (e.g., FibersOUT.vtk).
        length_image_output: Output length image (e.g., LengthImageOUT.nii.gz).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsintegrateVectorFieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTSINTEGRATE_VECTOR_FIELD_METADATA)
    cargs = []
    cargs.append("ANTSIntegrateVectorField")
    cargs.append(execution.input_file(vector_field_input))
    cargs.append(execution.input_file(roi_mask_input))
    cargs.append(fibers_output)
    cargs.append(length_image_output)
    ret = AntsintegrateVectorFieldOutputs(
        root=execution.output_file("."),
        fibers_out_vtk=execution.output_file(fibers_output),
        length_image_out_nii=execution.output_file(length_image_output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTSINTEGRATE_VECTOR_FIELD_METADATA",
    "AntsintegrateVectorFieldOutputs",
    "antsintegrate_vector_field",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__NO_EXT_METADATA = Metadata(
    id="e146bd1bed02e711ff41cccbd0a20832085fd087.boutiques",
    name="@NoExt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VNoExtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__no_ext(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """File name with specified extensions removed"""


def v__no_ext(
    extensions: list[str] | None = None,
    runner: Runner | None = None,
) -> VNoExtOutputs:
    """
    Tool for removing specified extensions from filenames.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        extensions: Extensions to be removed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VNoExtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__NO_EXT_METADATA)
    cargs = []
    cargs.append("@NoExt")
    cargs.append("<inputfile>")
    if extensions is not None:
        cargs.extend(extensions)
    ret = VNoExtOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("output"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VNoExtOutputs",
    "V__NO_EXT_METADATA",
    "v__no_ext",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BRAIN_VOYAGERTO_AFNI_METADATA = Metadata(
    id="6e57612e994ff9fb4392a1ea7a2df2f7bddd8e62.boutiques",
    name="3dBRAIN_VOYAGERtoAFNI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBrainVoyagertoAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_brain_voyagerto_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik_file: OutputPathType
    """Output BRIK file"""
    output_head_file: OutputPathType
    """Output HEAD file"""


def v_3d_brain_voyagerto_afni(
    input_file: InputPathType,
    force_byte_swap: bool = False,
    brainvoyager_qx: bool = False,
    tlrc_space: bool = False,
    acpc_space: bool = False,
    orig_space: bool = False,
    prefix: str | None = None,
    novolreg: bool = False,
    noxform: bool = False,
    set_environment: str | None = None,
    trace_debugging: bool = False,
    trace_extreme_debugging: bool = False,
    turn_off_memory_tracing: bool = False,
    turn_on_memory_tracing: bool = False,
    runner: Runner | None = None,
) -> V3dBrainVoyagertoAfniOutputs:
    """
    Converts a BrainVoyager vmr dataset to AFNI's BRIK format based on information
    from BrainVoyager's website.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input BrainVoyager VMR file.
        force_byte_swap: Force byte swapping.
        brainvoyager_qx: .vmr file is from BrainVoyager QX.
        tlrc_space: Dset in tlrc space.
        acpc_space: Dset in acpc-aligned space.
        orig_space: Dset in orig space.
        prefix: Prefix for output files.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        noxform: Same as -novolreg.
        set_environment: Set environment variable ENVname to be ENVvalue.\
            Quotes are necessary.
        trace_debugging: Turns on In/Out debug and Memory tracing.
        trace_extreme_debugging: Turns on extreme tracing.
        turn_off_memory_tracing: Turn off memory tracing.
        turn_on_memory_tracing: Turn on memory tracing (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBrainVoyagertoAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BRAIN_VOYAGERTO_AFNI_METADATA)
    cargs = []
    cargs.append("3dBRAIN_VOYAGERtoAFNI")
    cargs.extend([
        "--input",
        execution.input_file(input_file)
    ])
    if force_byte_swap:
        cargs.append("-bs")
    if brainvoyager_qx:
        cargs.append("-qx")
    if tlrc_space:
        cargs.append("-tlrc")
    if acpc_space:
        cargs.append("-acpc")
    if orig_space:
        cargs.append("-orig")
    if prefix is not None:
        cargs.extend([
            "--prefix",
            prefix
        ])
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if set_environment is not None:
        cargs.extend([
            "-setenv",
            set_environment
        ])
    if trace_debugging:
        cargs.append("-trace")
    if trace_extreme_debugging:
        cargs.append("-TRACE")
    if turn_off_memory_tracing:
        cargs.append("-nomall")
    if turn_on_memory_tracing:
        cargs.append("-yesmall")
    ret = V3dBrainVoyagertoAfniOutputs(
        root=execution.output_file("."),
        output_brik_file=execution.output_file("output.BRIK"),
        output_head_file=execution.output_file("output.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBrainVoyagertoAfniOutputs",
    "V_3D_BRAIN_VOYAGERTO_AFNI_METADATA",
    "v_3d_brain_voyagerto_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_ALIGN_ORIGIN_METADATA = Metadata(
    id="6857aca2f492ef8646affc2ca57d3ca2675b0b13.boutiques",
    name="antsAlignOrigin",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsAlignOriginOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_align_origin(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_image: OutputPathType
    """The output is the aligned image."""


def ants_align_origin(
    input_: InputPathType,
    reference_image: InputPathType,
    output: InputPathType,
    dimensionality: typing.Literal[2, 3] | None = None,
    runner: Runner | None = None,
) -> AntsAlignOriginOutputs:
    """
    antsAlignOrigin, applied to an input image, transforms it according to a
    reference image and a transform (or a set of transforms).
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_: Currently, the only input objects supported are image objects.\
            However, the current framework allows for warping of other objects such\
            as meshes and point sets.
        reference_image: For warping input images, the reference image defines\
            the spacing, origin, size, and direction of the output warped image.
        output: One can either output the warped image or, if the boolean is\
            set, one can print out the displacement field based on the composite\
            transform and the reference image.
        dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, antsWarp tries to infer\
            the dimensionality from the input image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsAlignOriginOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_ALIGN_ORIGIN_METADATA)
    cargs = []
    cargs.append("antsAlignOrigin")
    if dimensionality is not None:
        cargs.extend([
            "--dimensionality",
            str(dimensionality)
        ])
    cargs.extend([
        "--input",
        execution.input_file(input_)
    ])
    cargs.extend([
        "--reference-image",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "--output",
        execution.input_file(output)
    ])
    ret = AntsAlignOriginOutputs(
        root=execution.output_file("."),
        aligned_image=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_ALIGN_ORIGIN_METADATA",
    "AntsAlignOriginOutputs",
    "ants_align_origin",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PLOT_STRUCTURE_STATS_TCL_METADATA = Metadata(
    id="a74a29bbca7b8c304af58dc63af9e2298f4ac223.boutiques",
    name="plot_structure_stats.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PlotStructureStatsTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `plot_structure_stats_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    plot_file: OutputPathType
    """Generated plot"""


def plot_structure_stats_tcl(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> PlotStructureStatsTclOutputs:
    """
    Script to plot structural statistics.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input stats file.
        output_file: Output plot file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PlotStructureStatsTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PLOT_STRUCTURE_STATS_TCL_METADATA)
    cargs = []
    cargs.append("plot_structure_stats")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = PlotStructureStatsTclOutputs(
        root=execution.output_file("."),
        plot_file=execution.output_file(output_file + ".png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PLOT_STRUCTURE_STATS_TCL_METADATA",
    "PlotStructureStatsTclOutputs",
    "plot_structure_stats_tcl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TOUTCOUNT_METADATA = Metadata(
    id="b726a8742694b4a0acfdfd929608a00118e5b42b.boutiques",
    name="3dToutcount",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dToutcountOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_toutcount(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_afni_head: OutputPathType | None
    """Output dataset in AFNI format (HEAD file)."""
    output_afni_brik: OutputPathType | None
    """Output dataset in AFNI format (BRIK file)."""


def v_3d_toutcount(
    input_dataset: str,
    output_prefix: str | None = None,
    mask_dataset: str | None = None,
    q_threshold: float | None = None,
    autoclip: bool = False,
    automask: bool = False,
    fraction: bool = False,
    range_: bool = False,
    polort_order: float | None = None,
    legendre: bool = False,
    runner: Runner | None = None,
) -> V3dToutcountOutputs:
    """
    Calculates the number of 'outliers' in a 3D+time dataset at each time point.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input 3D+time dataset (e.g. dataset+orig).
        output_prefix: Prefix of the new dataset saved with the outlier Q\
            values, applicable with the -save option.
        mask_dataset: Only count voxels in the provided mask dataset.
        q_threshold: Use 'q' instead of 0.001 in the calculation of alpha. Must\
            be within range 0 < q < 1.
        autoclip: Clip off 'small' voxels (as in 3dClipLevel). Cannot use with\
            -mask.
        automask: Automatically mask the dataset. Cannot use with -mask.
        fraction: Output the fraction of (masked) voxels which are outliers at\
            each time point, instead of the count.
        range_: Print out median+3.5*MAD of outlier count with each time point.
        polort_order: Detrend each voxel time series with polynomials of order\
            'nn'. Default value is 0, which removes the median.
        legendre: Use Legendre polynomials for detrending (also allows -polort\
            > 3).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dToutcountOutputs`).
    """
    if q_threshold is not None and not (0 <= q_threshold <= 1): 
        raise ValueError(f"'q_threshold' must be between 0 <= x <= 1 but was {q_threshold}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TOUTCOUNT_METADATA)
    cargs = []
    cargs.append("3dToutcount")
    cargs.append(input_dataset)
    if output_prefix is not None:
        cargs.append(output_prefix)
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            mask_dataset
        ])
    if q_threshold is not None:
        cargs.extend([
            "-qthr",
            str(q_threshold)
        ])
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if fraction:
        cargs.append("-fraction")
    if range_:
        cargs.append("-range")
    if polort_order is not None:
        cargs.extend([
            "-polort",
            str(polort_order)
        ])
    if legendre:
        cargs.append("-legendre")
    ret = V3dToutcountOutputs(
        root=execution.output_file("."),
        output_afni_head=execution.output_file(output_prefix + ".HEAD") if (output_prefix is not None) else None,
        output_afni_brik=execution.output_file(output_prefix + ".BRIK") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dToutcountOutputs",
    "V_3D_TOUTCOUNT_METADATA",
    "v_3d_toutcount",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_RESAMPLE_METADATA = Metadata(
    id="d969759c0a9b6cf50715a3f792dc5b6638eb9982.boutiques",
    name="surface-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class SurfaceResampleAreaSurfs:
    """
    specify surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant surface with <current-sphere> mesh"""
    new_area: InputPathType
    """a relevant surface with <new-sphere> mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class SurfaceResampleAreaMetrics:
    """
    specify vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for <current-sphere> mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for <new-sphere> mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


class SurfaceResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output surface file"""


def surface_resample(
    surface_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    surface_out: str,
    area_surfs: SurfaceResampleAreaSurfs | None = None,
    area_metrics: SurfaceResampleAreaMetrics | None = None,
    opt_bypass_sphere_check: bool = False,
    runner: Runner | None = None,
) -> SurfaceResampleOutputs:
    """
    Resample a surface to a different mesh.
    
    Resamples a surface file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified. This method is not generally recommended for surface
    resampling, but is provided for completeness.
    
    The BARYCENTRIC method is generally recommended for anatomical surfaces, in
    order to minimize smoothing.
    
    For cut surfaces (including flatmaps), use -surface-cut-resample.
    
    Instead of resampling a spherical surface, the
    -surface-sphere-project-unproject command is recommended.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_in: the surface file to resample.
        current_sphere: a sphere surface with the mesh that the input surface\
            is currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        surface_out: the output surface file.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-resample")
    cargs.append(execution.input_file(surface_in))
    cargs.append(execution.input_file(current_sphere))
    cargs.append(execution.input_file(new_sphere))
    cargs.append(method)
    cargs.append(surface_out)
    if area_surfs is not None:
        cargs.extend(area_surfs.run(execution))
    if area_metrics is not None:
        cargs.extend(area_metrics.run(execution))
    if opt_bypass_sphere_check:
        cargs.append("-bypass-sphere-check")
    ret = SurfaceResampleOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_RESAMPLE_METADATA",
    "SurfaceResampleAreaMetrics",
    "SurfaceResampleAreaSurfs",
    "SurfaceResampleOutputs",
    "surface_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BMEDITS2SURF_METADATA = Metadata(
    id="be18624e39ce9efc3a4eb4744be1016b11c9fa5f.boutiques",
    name="bmedits2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Bmedits2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bmedits2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    lh_bmerase: OutputPathType
    """Binary mask of erased surface locations for the left hemisphere in
    fsaverage space."""
    rh_bmerase: OutputPathType
    """Binary mask of erased surface locations for the right hemisphere in
    fsaverage space."""
    lh_bmclone: OutputPathType
    """Binary mask of cloned surface locations for the left hemisphere in
    fsaverage space."""
    rh_bmclone: OutputPathType
    """Binary mask of cloned surface locations for the right hemisphere in
    fsaverage space."""
    bmclone_stats: OutputPathType
    """Statistics about the number of voxels cloned."""
    bmerase_stats: OutputPathType
    """Statistics about the number of voxels erased."""


def bmedits2surf(
    subject: str,
    self: bool = False,
    overwrite: bool = False,
    tmp_dir: str | None = None,
    cleanup: bool = False,
    no_cleanup: bool = False,
    debug: bool = False,
    left_hemisphere: bool = False,
    right_hemisphere: bool = False,
    no_surfs: bool = False,
    runner: Runner | None = None,
) -> Bmedits2surfOutputs:
    """
    Computes a binary map of surface locations where the brainmask.mgz has been
    edited.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: The subject for which the binary map will be computed.
        overwrite: Force overwriting of existing results.
        tmp_dir: Temporary directory.
        cleanup: Clean up temporary files.
        no_cleanup: Do not clean up temporary files.
        debug: Enable debug mode.
        left_hemisphere: Perform operation only on the left hemisphere.
        right_hemisphere: Perform operation only on the right hemisphere.
        no_surfs: Do not compute surfaces, only statistics.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Bmedits2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BMEDITS2SURF_METADATA)
    cargs = []
    cargs.append("bmedits2surf")
    cargs.extend([
        "-s",
        "-" + subject
    ])
    if self:
        cargs.append("--self")
    if overwrite:
        cargs.append("--overwrite")
    if tmp_dir is not None:
        cargs.extend([
            "--tmp",
            tmp_dir
        ])
    if cleanup:
        cargs.append("--cleanup")
    if no_cleanup:
        cargs.append("--no-cleanup")
    if debug:
        cargs.append("--debug")
    if left_hemisphere:
        cargs.append("--lh")
    if right_hemisphere:
        cargs.append("--rh")
    if no_surfs:
        cargs.append("--no-surfs")
    ret = Bmedits2surfOutputs(
        root=execution.output_file("."),
        lh_bmerase=execution.output_file(subject + "/surf/lh.bmerase.fsa.mgh"),
        rh_bmerase=execution.output_file(subject + "/surf/rh.bmerase.fsa.mgh"),
        lh_bmclone=execution.output_file(subject + "/surf/lh.bmclone.fsa.mgh"),
        rh_bmclone=execution.output_file(subject + "/surf/rh.bmclone.fsa.mgh"),
        bmclone_stats=execution.output_file(subject + "/stats/bmclone.dat"),
        bmerase_stats=execution.output_file(subject + "/stats/bmerase.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BMEDITS2SURF_METADATA",
    "Bmedits2surfOutputs",
    "bmedits2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_SEGMENT_THALAMIC_NUCLEI_SH_METADATA = Metadata(
    id="58c7623548d514cfc3a6445924c9c49471329b52.boutiques",
    name="run_SegmentThalamicNuclei.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunSegmentThalamicNucleiShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_segment_thalamic_nuclei_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_segment_thalamic_nuclei_sh(
    mcr_root: str,
    args: list[str] | None = None,
    runner: Runner | None = None,
) -> RunSegmentThalamicNucleiShOutputs:
    """
    Script for segmenting thalamic nuclei using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mcr_root: The root directory of the deployed MATLAB Compiler Runtime\
            (MCR).
        args: Additional arguments for the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunSegmentThalamicNucleiShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_SEGMENT_THALAMIC_NUCLEI_SH_METADATA)
    cargs = []
    cargs.append("run_SegmentThalamicNuclei.sh")
    cargs.append(mcr_root)
    if args is not None:
        cargs.extend(args)
    ret = RunSegmentThalamicNucleiShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_SEGMENT_THALAMIC_NUCLEI_SH_METADATA",
    "RunSegmentThalamicNucleiShOutputs",
    "run_segment_thalamic_nuclei_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ROI_CORR_MAT_METADATA = Metadata(
    id="d30a28b9afde46895088e3c1489b3ceaf2e8ab86.boutiques",
    name="@ROI_Corr_Mat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRoiCorrMatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__roi_corr_mat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    matrix_1d: OutputPathType
    """Correlation matrix in .1D format"""
    matrix_brick: OutputPathType
    """Correlation matrix in .BRIK format"""


def v__roi_corr_mat(
    ts_vol: InputPathType,
    roi_vol: InputPathType,
    prefix: str,
    roisel: InputPathType | None = None,
    zval: bool = False,
    mat_opt: str | None = None,
    dirty: bool = False,
    keep_tmp: bool = False,
    echo: bool = False,
    verb: bool = False,
    runner: Runner | None = None,
) -> VRoiCorrMatOutputs:
    """
    Script to produce an NxN ROI correlation matrix of N ROIs.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        ts_vol: Time series volume.
        roi_vol: ROI volume.
        prefix: Use output for a prefix.
        roisel: Force processing of ROI label (integers) listed in ROISEL 1D\
            file.
        zval: Output a zscore version of the correlation matrix.
        mat_opt: Output matrix in different manners.
        dirty: Keep temporary files.
        keep_tmp: Keep temporary files.
        echo: Set echo (echo all commands to screen).
        verb: Verbose flag.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRoiCorrMatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ROI_CORR_MAT_METADATA)
    cargs = []
    cargs.append("@ROI_Corr_Mat")
    cargs.extend([
        "-ts",
        execution.input_file(ts_vol)
    ])
    cargs.extend([
        "-roi",
        execution.input_file(roi_vol)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if roisel is not None:
        cargs.extend([
            "-roisel",
            execution.input_file(roisel)
        ])
    if zval:
        cargs.append("-zval")
    if mat_opt is not None:
        cargs.extend([
            "-mat",
            mat_opt
        ])
    if dirty:
        cargs.append("-dirty")
    if keep_tmp:
        cargs.append("-keep_tmp")
    if echo:
        cargs.append("-echo")
    if verb:
        cargs.append("-verb")
    ret = VRoiCorrMatOutputs(
        root=execution.output_file("."),
        matrix_1d=execution.output_file(prefix + "_matrix.1D"),
        matrix_brick=execution.output_file(prefix + "_matrix.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRoiCorrMatOutputs",
    "V__ROI_CORR_MAT_METADATA",
    "v__roi_corr_mat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_AW_TABLEIZE_ROI_INFO_PY_METADATA = Metadata(
    id="a22785dcd6a5f1a8653a62de11c6b89177cc48a8.boutiques",
    name="adjunct_aw_tableize_roi_info.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctAwTableizeRoiInfoPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_aw_tableize_roi_info_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Text file containing ROI count/size information"""


def adjunct_aw_tableize_roi_info_py(
    output_file: str,
    warped_atlas: InputPathType,
    warped_mask: InputPathType,
    reference_atlas: InputPathType,
    reference_mask: InputPathType,
    modesmooth_value: float,
    runner: Runner | None = None,
) -> AdjunctAwTableizeRoiInfoPyOutputs:
    """
    A simple helper function for the fat_proc scripts that generates a text file
    containing ROI count/size information based on provided atlases and masks.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        output_file: Output file name.
        warped_atlas: Warped atlas of interest, with subbrick selector if\
            necessary.
        warped_mask: Mask for the warped atlas (same grid).
        reference_atlas: Reference atlas (unwarped), with subbrick selector if\
            necessary.
        reference_mask: Mask for the reference atlas (same grid).
        modesmooth_value: Modesmooth value, from modal smoothing used after\
            warping.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctAwTableizeRoiInfoPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_AW_TABLEIZE_ROI_INFO_PY_METADATA)
    cargs = []
    cargs.append("adjunct_aw_tableize_roi_info.py")
    cargs.append(output_file)
    cargs.append(execution.input_file(warped_atlas))
    cargs.append(execution.input_file(warped_mask))
    cargs.append(execution.input_file(reference_atlas))
    cargs.append(execution.input_file(reference_mask))
    cargs.append(str(modesmooth_value))
    ret = AdjunctAwTableizeRoiInfoPyOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_AW_TABLEIZE_ROI_INFO_PY_METADATA",
    "AdjunctAwTableizeRoiInfoPyOutputs",
    "adjunct_aw_tableize_roi_info_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_QBOLD_METADATA = Metadata(
    id="2e600bbcac1e7e271e2d687cec37980ee3a87346.boutiques",
    name="fabber_qbold",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FabberQboldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_qbold(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    paramnames_file: OutputPathType
    """File containing the names of the model parameters"""
    model_fit_file: OutputPathType
    """4D volume of the model prediction"""
    residuals_file: OutputPathType
    """4D volume of the residuals"""
    model_extras_file: OutputPathType
    """Additional model-specific timeseries data"""
    mvn_file: OutputPathType
    """File containing the final MVN distributions"""
    mean_file: OutputPathType
    """File containing the parameter means"""
    std_file: OutputPathType
    """File containing the parameter standard deviations"""
    var_file: OutputPathType
    """File containing the parameter variances"""
    zstat_file: OutputPathType
    """File containing the parameter Zstats"""
    noise_mean_file: OutputPathType
    """File containing the noise means"""
    noise_std_file: OutputPathType
    """File containing the noise standard deviations"""
    free_energy_file: OutputPathType
    """File containing the free energy, if calculated"""
    logfile: OutputPathType
    """Logfile of the execution"""


def fabber_qbold(
    output_dir: str,
    method: str,
    model: str,
    data: InputPathType,
    data_n: InputPathType | None = None,
    data_order: str | None = "interleave",
    mask: InputPathType | None = None,
    mt_n: float | None = None,
    suppdata: InputPathType | None = None,
    listmethods: bool = False,
    listmodels: bool = False,
    listparams: bool = False,
    descparams: bool = False,
    listoutputs: bool = False,
    evaluate: str | None = None,
    evaluate_params: str | None = None,
    evaluate_nt: float | None = None,
    simple_output: bool = False,
    overwrite: bool = False,
    link_latest: bool = False,
    loadmodels: InputPathType | None = None,
    dump_param_names: bool = False,
    save_model_fit: bool = False,
    save_residuals: bool = False,
    save_model_extras: bool = False,
    save_mvn: bool = False,
    save_mean: bool = False,
    save_std: bool = False,
    save_var: bool = False,
    save_zstat: bool = False,
    save_noise_mean: bool = False,
    save_noise_std: bool = False,
    save_free_energy: bool = False,
    optfile: InputPathType | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> FabberQboldOutputs:
    """
    Fabber - a flexible BaYesian modeling framework for FMRI and MRI analysis.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        output_dir: Directory for output files (including logfile).
        method: Use this inference method.
        model: Use this forward model.
        data: Specify a single input data file.
        data_n: Specify multiple data files for n=1, 2, 3...
        data_order: If multiple data files are specified, how they will be\
            handled: concatenate = one after the other, interleave = first record\
            from each file, then second, etc.
        mask: Mask file. Inference will only be performed where mask value > 0.
        mt_n: List of masked time points, indexed from 1. These will be ignored\
            in the parameter updates.
        suppdata: 'Supplemental' timeseries data, required for some models.
        listmethods: List all known inference methods.
        listmodels: List all known forward models.
        listparams: List model parameters (requires model configuration options\
            to be given).
        descparams: Descript model parameters (name, description, units) -\
            requires model configuration options to be given. Note that not all\
            models provide parameter descriptions.
        listoutputs: List additional model outputs (requires model\
            configuration options to be given).
        evaluate: Evaluate model. Set to name of output required or blank for\
            default output. Requires model configuration options, --evaluate-params\
            and --evaluate-nt.
        evaluate_params: List of parameter values for evaluation.
        evaluate_nt: Number of time points for evaluation - must be consistent\
            with model options where appropriate.
        simple_output: Instead of usual standard output, simply output series\
            of lines each giving progress as percentage.
        overwrite: If set will overwrite existing output. If not set, new\
            output directories will be created by appending '+' to the directory\
            name.
        link_latest: Try to create a link to the most recent output directory\
            with the prefix _latest.
        loadmodels: Load models dynamically from the specified filename, which\
            should be a DLL/shared library.
        dump_param_names: Write the file paramnames.txt containing the names of\
            the model parameters.
        save_model_fit: Output the model prediction as a 4d volume.
        save_residuals: Output the residuals (difference between the data and\
            the model prediction).
        save_model_extras: Output any additional model-specific timeseries data.
        save_mvn: Output the final MVN distributions.
        save_mean: Output the parameter means.
        save_std: Output the parameter standard deviations.
        save_var: Output the parameter variances.
        save_zstat: Output the parameter Zstats.
        save_noise_mean: Output the noise means. The noise distribution\
            inferred is the precision of a Gaussian noise source.
        save_noise_std: Output the noise standard deviations.
        save_free_energy: Output the free energy, if calculated.
        optfile: File containing additional options, one per line, in the same\
            form as specified on the command line.
        debug: Output large amounts of debug information. ONLY USE WITH VERY\
            SMALL NUMBERS OF VOXELS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberQboldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_QBOLD_METADATA)
    cargs = []
    cargs.append("fabber_qbold")
    cargs.extend([
        "--output",
        output_dir
    ])
    cargs.extend([
        "--method",
        method
    ])
    cargs.extend([
        "--model",
        model
    ])
    cargs.extend([
        "--data",
        execution.input_file(data)
    ])
    if data_n is not None:
        cargs.extend([
            "--data<n>",
            execution.input_file(data_n)
        ])
    if data_order is not None:
        cargs.extend([
            "--data-order",
            data_order
        ])
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if mt_n is not None:
        cargs.extend([
            "--mt<n>",
            str(mt_n)
        ])
    if suppdata is not None:
        cargs.extend([
            "--suppdata",
            execution.input_file(suppdata)
        ])
    if listmethods:
        cargs.append("--listmethods")
    if listmodels:
        cargs.append("--listmodels")
    if listparams:
        cargs.append("--listparams")
    if descparams:
        cargs.append("--descparams")
    if listoutputs:
        cargs.append("--listoutputs")
    if evaluate is not None:
        cargs.extend([
            "--evaluate",
            evaluate
        ])
    if evaluate_params is not None:
        cargs.extend([
            "--evaluate-params",
            evaluate_params
        ])
    if evaluate_nt is not None:
        cargs.extend([
            "--evaluate-nt",
            str(evaluate_nt)
        ])
    if simple_output:
        cargs.append("--simple-output")
    if overwrite:
        cargs.append("--overwrite")
    if link_latest:
        cargs.append("--link-to-latest")
    if loadmodels is not None:
        cargs.extend([
            "--loadmodels",
            execution.input_file(loadmodels)
        ])
    if dump_param_names:
        cargs.append("--dump-param-names")
    if save_model_fit:
        cargs.append("--save-model-fit")
    if save_residuals:
        cargs.append("--save-residuals")
    if save_model_extras:
        cargs.append("--save-model-extras")
    if save_mvn:
        cargs.append("--save-mvn")
    if save_mean:
        cargs.append("--save-mean")
    if save_std:
        cargs.append("--save-std")
    if save_var:
        cargs.append("--save-var")
    if save_zstat:
        cargs.append("--save-zstat")
    if save_noise_mean:
        cargs.append("--save-noise-mean")
    if save_noise_std:
        cargs.append("--save-noise-std")
    if save_free_energy:
        cargs.append("--save-free-energy")
    if optfile is not None:
        cargs.extend([
            "--optfile",
            execution.input_file(optfile)
        ])
    if debug:
        cargs.append("--debug")
    ret = FabberQboldOutputs(
        root=execution.output_file("."),
        paramnames_file=execution.output_file(output_dir + "/paramnames.txt"),
        model_fit_file=execution.output_file(output_dir + "/model_fit.nii.gz"),
        residuals_file=execution.output_file(output_dir + "/residuals.nii.gz"),
        model_extras_file=execution.output_file(output_dir + "/model_extras.nii.gz"),
        mvn_file=execution.output_file(output_dir + "/mvn.nii.gz"),
        mean_file=execution.output_file(output_dir + "/mean.nii.gz"),
        std_file=execution.output_file(output_dir + "/std.nii.gz"),
        var_file=execution.output_file(output_dir + "/var.nii.gz"),
        zstat_file=execution.output_file(output_dir + "/zstat.nii.gz"),
        noise_mean_file=execution.output_file(output_dir + "/noise_mean.nii.gz"),
        noise_std_file=execution.output_file(output_dir + "/noise_std.nii.gz"),
        free_energy_file=execution.output_file(output_dir + "/free_energy.nii.gz"),
        logfile=execution.output_file(output_dir + "/logfile.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_QBOLD_METADATA",
    "FabberQboldOutputs",
    "fabber_qbold",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_DCE_METADATA = Metadata(
    id="8503b8f2dd7017cdd9be4bac37b326badcc8e524.boutiques",
    name="fabber_dce",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FabberDceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_dce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Files generated by Fabber DCE"""


def fabber_dce(
    output_directory: str,
    inference_method: str,
    forward_model: str,
    input_data: InputPathType,
    help_flag: bool = False,
    list_methods: bool = False,
    list_models: bool = False,
    list_params: bool = False,
    describe_params: bool = False,
    list_outputs: bool = False,
    evaluate_model: str | None = None,
    evaluate_params: list[float] | None = None,
    evaluate_nt: float | None = None,
    simple_output: bool = False,
    overwrite: bool = False,
    link_to_latest: bool = False,
    load_models: InputPathType | None = None,
    multiple_data: list[InputPathType] | None = None,
    data_order: str | None = "interleave",
    mask: InputPathType | None = None,
    masked_time_points: list[float] | None = None,
    supplemental_data: InputPathType | None = None,
    dump_param_names: bool = False,
    save_model_fit: bool = False,
    save_residuals: bool = False,
    save_model_extras: bool = False,
    save_mvn: bool = False,
    save_mean: bool = False,
    save_std: bool = False,
    save_variances: bool = False,
    save_zstat: bool = False,
    save_noise_mean: bool = False,
    save_noise_std: bool = False,
    save_free_energy: bool = False,
    option_file: InputPathType | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> FabberDceOutputs:
    """
    Fabber DCE analysis tool for model-based analysis of dynamic contrast-enhanced
    imaging data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        output_directory: Directory for output files (including logfile).
        inference_method: Inference method to use.
        forward_model: Forward model to use.
        input_data: Single input data file.
        help_flag: Print this usage message.
        list_methods: List all known inference methods.
        list_models: List all known forward models.
        list_params: List model parameters (requires model configuration\
            options to be given).
        describe_params: Describe model parameters (name, description, units) -\
            requires model configuration options to be given.
        list_outputs: List additional model outputs (requires model\
            configuration options to be given).
        evaluate_model: Evaluate model. Set to name of output required or blank\
            for default output. Requires model configuration options,\
            --evaluate-params and --evaluate-nt.
        evaluate_params: List of parameter values for evaluation.
        evaluate_nt: Number of time points for evaluation - must be consistent\
            with model options where appropriate.
        simple_output: Instead of usual output, simply output series of lines\
            each giving progress as percentage.
        overwrite: If set will overwrite existing output. If not set, new\
            output directories will be created by appending '+' to the directory\
            name.
        link_to_latest: Try to create a link to the most recent output\
            directory with the prefix _latest.
        load_models: Load models dynamically from the specified filename, which\
            should be a DLL/shared library.
        multiple_data: Specify multiple data files for n=1, 2, 3...
        data_order: If multiple data files are specified, how they will be\
            handled: concatenate = one after the other, interleave = first record\
            from each file, then second, etc.
        mask: Mask file. Inference will only be performed where mask value > 0.
        masked_time_points: List of masked time points, indexed from 1. These\
            will be ignored in the parameter updates.
        supplemental_data: 'Supplemental' timeseries data, required for some\
            models.
        dump_param_names: Write the file paramnames.txt containing the names of\
            the model parameters.
        save_model_fit: Output the model prediction as a 4D volume.
        save_residuals: Output the residuals (difference between the data and\
            the model prediction).
        save_model_extras: Output any additional model-specific timeseries data.
        save_mvn: Output the final MVN distributions.
        save_mean: Output the parameter means.
        save_std: Output the parameter standard deviations.
        save_variances: Output the parameter variances.
        save_zstat: Output the parameter Z-stats.
        save_noise_mean: Output the noise means. The noise distribution\
            inferred is the precision of a Gaussian noise source.
        save_noise_std: Output the noise standard deviations.
        save_free_energy: Output the free energy, if calculated.
        option_file: File containing additional options, one per line, in the\
            same form as specified on the command line.
        debug: Output large amounts of debug information. ONLY USE WITH VERY\
            SMALL NUMBERS OF VOXELS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberDceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_DCE_METADATA)
    cargs = []
    cargs.append("fabber_dce")
    cargs.extend([
        "--output",
        output_directory
    ])
    cargs.extend([
        "--method",
        inference_method
    ])
    cargs.extend([
        "--model",
        forward_model
    ])
    cargs.extend([
        "--data",
        execution.input_file(input_data)
    ])
    if help_flag:
        cargs.append("--help")
    if list_methods:
        cargs.append("--listmethods")
    if list_models:
        cargs.append("--listmodels")
    if list_params:
        cargs.append("--listparams")
    if describe_params:
        cargs.append("--descparams")
    if list_outputs:
        cargs.append("--listoutputs")
    if evaluate_model is not None:
        cargs.extend([
            "--evaluate",
            evaluate_model
        ])
    if evaluate_params is not None:
        cargs.extend([
            "--evaluate-params",
            *map(str, evaluate_params)
        ])
    if evaluate_nt is not None:
        cargs.extend([
            "--evaluate-nt",
            str(evaluate_nt)
        ])
    if simple_output:
        cargs.append("--simple-output")
    if overwrite:
        cargs.append("--overwrite")
    if link_to_latest:
        cargs.append("--link-to-latest")
    if load_models is not None:
        cargs.extend([
            "--loadmodels",
            execution.input_file(load_models)
        ])
    if multiple_data is not None:
        cargs.extend([
            "--data<n>",
            *[execution.input_file(f) for f in multiple_data]
        ])
    if data_order is not None:
        cargs.extend([
            "--data-order",
            data_order
        ])
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if masked_time_points is not None:
        cargs.extend([
            "--mt<n>",
            *map(str, masked_time_points)
        ])
    if supplemental_data is not None:
        cargs.extend([
            "--suppdata",
            execution.input_file(supplemental_data)
        ])
    if dump_param_names:
        cargs.append("--dump-param-names")
    if save_model_fit:
        cargs.append("--save-model-fit")
    if save_residuals:
        cargs.append("--save-residuals")
    if save_model_extras:
        cargs.append("--save-model-extras")
    if save_mvn:
        cargs.append("--save-mvn")
    if save_mean:
        cargs.append("--save-mean")
    if save_std:
        cargs.append("--save-std")
    if save_variances:
        cargs.append("--save-var")
    if save_zstat:
        cargs.append("--save-zstat")
    if save_noise_mean:
        cargs.append("--save-noise-mean")
    if save_noise_std:
        cargs.append("--save-noise-std")
    if save_free_energy:
        cargs.append("--save-free-energy")
    if option_file is not None:
        cargs.extend([
            "--optfile",
            execution.input_file(option_file)
        ])
    if debug:
        cargs.append("--debug")
    ret = FabberDceOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_directory + "/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_DCE_METADATA",
    "FabberDceOutputs",
    "fabber_dce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_THALAMIC_NUCLEI_METADATA = Metadata(
    id="6d4f3bd43ea02912a67101dc7d2bc3abdee4ebd2.boutiques",
    name="SegmentThalamicNuclei",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentThalamicNucleiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_thalamic_nuclei(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    seg_output: OutputPathType
    """The output segmentation file of thalamic nuclei."""


def segment_thalamic_nuclei(
    t1_image: InputPathType,
    output_dir: str,
    runner: Runner | None = None,
) -> SegmentThalamicNucleiOutputs:
    """
    A tool for segmenting thalamic nuclei using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_image: The T1-weighted image to process.
        output_dir: Directory to store segmentation results.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentThalamicNucleiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_THALAMIC_NUCLEI_METADATA)
    cargs = []
    cargs.append("SegmentThalamicNuclei")
    cargs.append(execution.input_file(t1_image))
    cargs.append(output_dir)
    ret = SegmentThalamicNucleiOutputs(
        root=execution.output_file("."),
        seg_output=execution.output_file(output_dir + "/thalamic_nuclei_seg.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_THALAMIC_NUCLEI_METADATA",
    "SegmentThalamicNucleiOutputs",
    "segment_thalamic_nuclei",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_MAKE_SPEC_CARET_METADATA = Metadata(
    id="950a20d0f240b4840873e5b78497c9b7e5e19277.boutiques",
    name="@SUMA_Make_Spec_Caret",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaMakeSpecCaretOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_make_spec_caret(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    left_hemisphere_spec: OutputPathType
    """Output spec file for the left hemisphere"""
    right_hemisphere_spec: OutputPathType
    """Output spec file for the right hemisphere"""


def v__suma_make_spec_caret(
    subject_id: str,
    runner: Runner | None = None,
) -> VSumaMakeSpecCaretOutputs:
    """
    Prepare surfaces for viewing in SUMA, tested with Caret-5.2 surfaces.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        subject_id: Subject ID for file naming.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaMakeSpecCaretOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_MAKE_SPEC_CARET_METADATA)
    cargs = []
    cargs.append("@SUMA_Make_Spec_Caret")
    cargs.append("[OPTIONS]")
    cargs.extend([
        "-sid",
        subject_id
    ])
    ret = VSumaMakeSpecCaretOutputs(
        root=execution.output_file("."),
        left_hemisphere_spec=execution.output_file(subject_id + "_lh.spec"),
        right_hemisphere_spec=execution.output_file(subject_id + "_rh.spec"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaMakeSpecCaretOutputs",
    "V__SUMA_MAKE_SPEC_CARET_METADATA",
    "v__suma_make_spec_caret",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHERE_SUBJECT_METADATA = Metadata(
    id="1b01c8e4cff0b051c46d47179ad938955066fe57.boutiques",
    name="sphere_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SphereSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sphere_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_result: OutputPathType
    """Output of the sphere_subject execution."""


def sphere_subject(
    input_dir: str,
    output_file: str,
    license_file: str | None = "/usr/local/freesurfer/.license",
    runner: Runner | None = None,
) -> SphereSubjectOutputs:
    """
    A FreeSurfer tool for processing subject data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_dir: Input subject directory.
        output_file: Output file for results.
        license_file: Path to FreeSurfer license file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SphereSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHERE_SUBJECT_METADATA)
    cargs = []
    cargs.append("sphere_subject")
    cargs.append(input_dir)
    cargs.append(output_file)
    if license_file is not None:
        cargs.append(license_file)
    ret = SphereSubjectOutputs(
        root=execution.output_file("."),
        output_result=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHERE_SUBJECT_METADATA",
    "SphereSubjectOutputs",
    "sphere_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_DSET_METADATA = Metadata(
    id="844cbaec7e78b76addf8794c6d75de087e117e30.boutiques",
    name="ConvertDset",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ConvertDsetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_dset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_dataset: OutputPathType | None
    """Converted dataset output"""


def convert_dset(
    output_type: list[typing.Literal["niml_asc", "niml_bi", "1D", "1Dp", "1Dpt", "gii", "gii_asc", "gii_b64", "gii_b64gz", "1D_stderr", "1D_stdout", "niml_stderr", "niml_stdout", "1Dp_stdout", "1Dp_stderr", "1Dpt_stdout", "1Dpt_stderr"]],
    input_dataset: InputPathType,
    input_type: typing.Literal["niml", "1D", "dx"] | None = None,
    output_prefix: str | None = None,
    dset_labels: str | None = None,
    add_node_index: bool = False,
    node_index_file: InputPathType | None = None,
    node_select_file: InputPathType | None = None,
    prepend_node_index: bool = False,
    pad_to_node: str | None = None,
    labelize: InputPathType | None = None,
    graphize: bool = False,
    graph_nodelist: str | None = None,
    graph_full_nodelist: InputPathType | None = None,
    graph_named_nodelist: str | None = None,
    graph_xyz_lpi: bool = False,
    graph_edgelist: InputPathType | None = None,
    onegraph: bool = False,
    multigraph: bool = False,
    split: int | None = None,
    no_history: bool = False,
    runner: Runner | None = None,
) -> ConvertDsetOutputs:
    """
    Converts a surface dataset from one format to another.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        output_type: Type of output datasets.
        input_dataset: Input dataset to be converted.
        input_type: Type of input datasets.
        output_prefix: Output prefix for dataset.
        dset_labels: Label the columns (sub-bricks) of the output dataset.
        add_node_index: Add a node index element if one does not exist in the\
            input dataset.
        node_index_file: File containing node indices.
        node_select_file: File specifying the nodes to keep in the output.
        prepend_node_index: Add a node index column to the data.
        pad_to_node: Output a full dataset from node 0 to MAX_INDEX.
        labelize: Turn the dataset into a labeled set per the colormap in CMAP.
        graphize: Turn the dataset into a SUMA graph dataset.
        graph_nodelist: Two files specifying the indices and the coordinates of\
            the graph's nodes.
        graph_full_nodelist: Similar to -graph_nodelist_1D but without need for\
            NODEINDLIST.1D.
        graph_named_nodelist: Two files specifying graph node indices, string\
            labels, and their coordinates.
        graph_xyz_lpi: Coordinates in NodeList.1D are in LPI instead of RAI.
        graph_edgelist: Indices of graph nodes defining edge.
        onegraph: Expect input dataset to be one square matrix defining the\
            graph (default).
        multigraph: Expect each column in input dataset to define an entire\
            graph.
        split: Split a multi-column dataset into about N output datasets.
        no_history: Do not include a history element in the output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertDsetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_DSET_METADATA)
    cargs = []
    cargs.append("ConvertDset")
    cargs.extend([
        "-o_",
        *output_type
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if input_type is not None:
        cargs.extend([
            "-i_",
            input_type
        ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if dset_labels is not None:
        cargs.extend([
            "-dset_labels",
            dset_labels
        ])
    if add_node_index:
        cargs.append("-add_node_index")
    if node_index_file is not None:
        cargs.extend([
            "-node_index_1D",
            execution.input_file(node_index_file)
        ])
    if node_select_file is not None:
        cargs.extend([
            "-node_select_1D",
            execution.input_file(node_select_file)
        ])
    if prepend_node_index:
        cargs.append("-prepend_node_index_1D")
    if pad_to_node is not None:
        cargs.extend([
            "-pad_to_node",
            pad_to_node
        ])
    if labelize is not None:
        cargs.extend([
            "-labelize",
            execution.input_file(labelize)
        ])
    if graphize:
        cargs.append("-graphize")
    if graph_nodelist is not None:
        cargs.extend([
            "-graph_nodelist_1D",
            graph_nodelist
        ])
    if graph_full_nodelist is not None:
        cargs.extend([
            "-graph_full_nodelist_1D",
            execution.input_file(graph_full_nodelist)
        ])
    if graph_named_nodelist is not None:
        cargs.extend([
            "-graph_named_nodelist_txt",
            graph_named_nodelist
        ])
    if graph_xyz_lpi:
        cargs.append("-graph_XYZ_LPI")
    if graph_edgelist is not None:
        cargs.extend([
            "-graph_edgelist_1D",
            execution.input_file(graph_edgelist)
        ])
    if onegraph:
        cargs.append("-onegraph")
    if multigraph:
        cargs.append("-multigraph")
    if split is not None:
        cargs.extend([
            "-split",
            str(split)
        ])
    if no_history:
        cargs.append("-no_history")
    ret = ConvertDsetOutputs(
        root=execution.output_file("."),
        converted_dataset=execution.output_file(output_prefix) if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_DSET_METADATA",
    "ConvertDsetOutputs",
    "convert_dset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NU_CORRECT_MNI_METADATA = Metadata(
    id="4aed4300ad41fe97f4d8b814e65b6654469e83cc.boutiques",
    name="mri_nu_correct.mni",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNuCorrectMniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_nu_correct_mni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_output: OutputPathType
    """Corrected output volume."""


def mri_nu_correct_mni(
    input_volume: InputPathType,
    output_volume: str,
    iterations: float,
    proto_iterations: float | None = None,
    mask_volume: InputPathType | None = None,
    stop_threshold: float | None = None,
    uchar_transform: InputPathType | None = None,
    ants_n3: bool = False,
    ants_n4: bool = False,
    no_uchar: bool = False,
    ants_n4_replace_zeros: bool = False,
    cm_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> MriNuCorrectMniOutputs:
    """
    Wrapper for nu_correct, used for correcting intensity non-uniformity (bias
    fields).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume. Can be any format accepted by mri_convert.
        output_volume: Output volume. Can be any format accepted by\
            mri_convert.
        iterations: Number of iterations to run nu_correct. Default is 4.
        proto_iterations: Passes as argument of the -iterations flag of\
            nu_correct.
        mask_volume: Brainmask volume. Can be any format accepted by\
            mri_convert.
        stop_threshold: Threshold for stopping iteration. Suggest values\
            between 0.01 to 0.0001.
        uchar_transform: Use mri_make_uchar instead of conforming.
        ants_n3: Run N3 using ANTS N3BiasFieldCorrection.
        ants_n4: Run N4 using ANTS N4BiasFieldCorrection.
        no_uchar: Do not use mri_make_uchar (default).
        ants_n4_replace_zeros: Replace 0s with small random numbers then remove\
            after nu correction.
        cm_flag: For use with data that is higher than 1mm resolution.
        debug_flag: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNuCorrectMniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NU_CORRECT_MNI_METADATA)
    cargs = []
    cargs.append("mri_nu_correct.mni")
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--o",
        output_volume
    ])
    cargs.extend([
        "--n",
        str(iterations)
    ])
    if proto_iterations is not None:
        cargs.extend([
            "--proto-iters",
            str(proto_iterations)
        ])
    if mask_volume is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_volume)
        ])
    if stop_threshold is not None:
        cargs.extend([
            "--stop",
            str(stop_threshold)
        ])
    if uchar_transform is not None:
        cargs.extend([
            "--uchar",
            execution.input_file(uchar_transform)
        ])
    if ants_n3:
        cargs.append("--ants-n3")
    if ants_n4:
        cargs.append("--ants-n4")
    if no_uchar:
        cargs.append("--no-uchar")
    if ants_n4_replace_zeros:
        cargs.append("--ants-n4-replace-zeros")
    if cm_flag:
        cargs.append("--cm")
    if debug_flag:
        cargs.append("--debug")
    ret = MriNuCorrectMniOutputs(
        root=execution.output_file("."),
        corrected_output=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NU_CORRECT_MNI_METADATA",
    "MriNuCorrectMniOutputs",
    "mri_nu_correct_mni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WARPCONVERT_METADATA = Metadata(
    id="aa820be224a359dcdb4d3911882f1ee399c31903.boutiques",
    name="warpconvert",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class WarpconvertConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class WarpconvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `warpconvert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out: OutputPathType
    """the output warp image."""


def warpconvert(
    in_: InputPathType,
    type_: str,
    out: str,
    template: InputPathType | None = None,
    midway_space: bool = False,
    from_: int | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[WarpconvertConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> WarpconvertOutputs:
    """
    Convert between different representations of a non-linear warp.
    
    A deformation field is defined as an image where each voxel defines the
    corresponding position in the other image (in scanner space coordinates). A
    displacement field stores the displacements (in mm) to the other image from
    the each voxel's position (in scanner space). The warpfull file is the 5D
    format output from mrregister -nl_warp_full, which contains linear
    transforms, warps and their inverses that map each image to a midway space.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        in_: the input warp image.
        type_: the conversion type required. Valid choices are:\
            deformation2displacement, displacement2deformation,\
            warpfull2deformation, warpfull2displacement.
        out: the output warp image.
        template: define a template image when converting a warpfull file\
            (which is defined on a grid in the midway space between image 1 & 2).\
            For example to generate the deformation field that maps image1 to\
            image2, then supply image2 as the template image.
        midway_space: to be used only with warpfull2deformation and\
            warpfull2displacement conversion types. The output will only contain\
            the non-linear warp to map an input image to the midway space (defined\
            by the warpfull grid). If a linear transform exists in the warpfull\
            file header then it will be composed and included in the output.
        from_: to be used only with warpfull2deformation and\
            warpfull2displacement conversion types. Used to define the direction of\
            the desired output field.Use -from 1 to obtain the image1->image2 field\
            and from 2 for image2->image1. Can be used in combination with the\
            -midway_space option to produce a field that only maps to midway space.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WarpconvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WARPCONVERT_METADATA)
    cargs = []
    cargs.append("warpconvert")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if midway_space:
        cargs.append("-midway_space")
    if from_ is not None:
        cargs.extend([
            "-from",
            str(from_)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(in_))
    cargs.append(type_)
    cargs.append(out)
    ret = WarpconvertOutputs(
        root=execution.output_file("."),
        out=execution.output_file(out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WARPCONVERT_METADATA",
    "WarpconvertConfig",
    "WarpconvertOutputs",
    "warpconvert",
]
